@@ -22,7 +22,7 @@ def main():
     engine_path = 'sqlite:///' + sqlite_name
     engine = sqlalchemy.create_engine(engine_path, isolation_level='SERIALIZABLE')
 
-    data_dict = {'value': cell_value}
+    data_dict = {'value': [cell_value]}
     df = pd.DataFrame(data_dict)
     df.to_sql(table_name, engine)
     return
